@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 from .nameditemlist import NamedItemList
 from .utils import create_description_from_et
 from .odxlink import OdxLinkId, OdxLinkDatabase, OdxDocFragment
@@ -11,17 +10,17 @@ from xml.etree import ElementTree
 from dataclasses import dataclass, field
 from typing import Optional, Any, Dict, List
 
-@dataclass()
+@dataclass
 class XDoc:
     short_name : str
-    long_name : Optional[str] = None
-    description : Optional[str] = None
-    number: Optional[str] = None
-    state: Optional[str] = None
-    date: Optional[str] = None
-    publisher: Optional[str] = None
-    url: Optional[str] = None
-    position: Optional[str] = None
+    long_name : Optional[str]
+    description : Optional[str]
+    number: Optional[str]
+    state: Optional[str]
+    date: Optional[str]
+    publisher: Optional[str]
+    url: Optional[str]
+    position: Optional[str]
 
     @staticmethod
     def from_et(xdoc) -> "XDoc":
@@ -46,10 +45,10 @@ class XDoc:
                     position=position,
                     )
 
-@dataclass()
+@dataclass
 class RelatedDoc:
-    description: Optional[str] = None
-    xdoc: Optional[XDoc] = None
+    description: Optional[str]
+    xdoc: Optional[XDoc]
 
     @staticmethod
     def from_et(et_element) -> "RelatedDoc":
@@ -63,10 +62,10 @@ class RelatedDoc:
                           )
 
 
-@dataclass()
+@dataclass
 class CompanySpecificInfo:
     related_docs: Optional[List[RelatedDoc]]
-    sdgs: List[SpecialDataGroup] = field(default_factory=list)
+    sdgs: List[SpecialDataGroup]
 
     @staticmethod
     def from_et(et_element, doc_frags: List[OdxDocFragment]) -> "CompanySpecificInfo":
@@ -95,20 +94,20 @@ class CompanySpecificInfo:
         for sdg in self.sdgs:
             sdg._resolve_references(odxlinks)
 
-@dataclass()
+@dataclass
 class TeamMember:
     odx_id: OdxLinkId
     short_name: str
-    long_name: Optional[str] = None
-    description: Optional[str] = None
-    roles: Optional[List[str]] = None
-    department: Optional[str] = None
-    address: Optional[str] = None
-    zip: Optional[str] = None
-    city: Optional[str] = None
-    phone: Optional[str] = None
-    fax: Optional[str] = None
-    email: Optional[str] = None
+    long_name: Optional[str]
+    description: Optional[str]
+    roles: Optional[List[str]]
+    department: Optional[str]
+    address: Optional[str]
+    zip: Optional[str]
+    city: Optional[str]
+    phone: Optional[str]
+    fax: Optional[str]
+    email: Optional[str]
 
     @staticmethod
     def from_et(et_element: ElementTree.Element,
@@ -149,15 +148,15 @@ class TeamMember:
                           email=email)
 
 
-@dataclass()
+@dataclass
 class CompanyData:
     odx_id: OdxLinkId
     short_name: str
-    long_name: Optional[str] = None
-    description: Optional[str] = None
-    roles: Optional[List[str]] = None
-    team_members: Optional[NamedItemList[TeamMember]] = None
-    company_specific_info: Optional[CompanySpecificInfo] = None
+    long_name: Optional[str]
+    description: Optional[str]
+    roles: Optional[List[str]]
+    team_members: NamedItemList[TeamMember]
+    company_specific_info: Optional[CompanySpecificInfo]
 
     @staticmethod
     def from_et(et_element, doc_frags: List[OdxDocFragment]) \
