@@ -1,7 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
-
 from typing import List
 
 from ..exceptions import DecodeError
@@ -10,10 +8,11 @@ from ..odxtypes import DataType
 from .compumethodbase import CompuMethod
 from .compuscale import CompuScale
 
-
 class TexttableCompuMethod(CompuMethod):
-    def __init__(self, internal_to_phys: List[CompuScale], internal_type):
-        super().__init__(internal_type, DataType.A_UNICODE2STRING, "TEXTTABLE")
+    def __init__(self, *, internal_to_phys: List[CompuScale], internal_type):
+        super().__init__(internal_type=internal_type,
+                         physical_type=DataType.A_UNICODE2STRING,
+                         category="TEXTTABLE")
         self.internal_to_phys = internal_to_phys
 
         assert all(scale.lower_limit is not None or scale.upper_limit is not None
