@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 from itertools import chain
 from pathlib import Path
 from typing import List, Optional, Set
@@ -26,8 +25,9 @@ class Database:
     """
 
     def __init__(self,
+                 *,
                  pdx_zip: Optional[ZipFile] = None,
-                 odx_d_file_name: Optional[str] = None):
+                 odx_d_file_name: Optional[str] = None) -> None:
 
         if pdx_zip is None and odx_d_file_name is None:
             # create an empty database object
