@@ -1,11 +1,10 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
-import abc
 from typing import cast, List, Dict, Optional, Any, Union
 from dataclasses import dataclass, field
 
-from .utils import create_description_from_et
+from .utils import create_description_from_et, short_name_as_id
+from .nameditemlist import NamedItemList
 from .odxtypes import odxstr_to_bool
 from .physicaltype import PhysicalType
 from .globals import logger
@@ -22,18 +21,19 @@ from .exceptions import DecodeError, EncodeError
 from .specialdata import SpecialDataGroup, create_sdgs_from_et
 from .odxlink import OdxLinkRef, OdxLinkId, OdxDocFragment, OdxLinkDatabase
 
-class DopBase(abc.ABC):
+class DopBase:
     """Base class for all DOPs.
 
     Any class that a parameter can reference via a DOP-REF should inherit from this class.
     """
 
     def __init__(self,
+                 *,
                  odx_id,
                  short_name,
-                 long_name=None,
-                 description=None,
-                 is_visible_raw=None,
+                 long_name,
+                 description,
+                 is_visible_raw,
                  sdgs = []):
         self.odx_id = odx_id
         self.short_name = short_name
@@ -58,31 +58,29 @@ class DopBase(abc.ABC):
     def is_visible(self) -> bool:
         return self.is_visible_raw in (None, True)
 
-    @abc.abstractmethod
     def convert_physical_to_bytes(self, physical_value, encode_state: EncodeState, bit_position: int) -> bytes:
         """Convert the physical value into bytes."""
-        pass
+        raise NotImplementedError
 
-    @abc.abstractmethod
     def convert_bytes_to_physical(self, decode_state: DecodeState, bit_position: int = 0):
         """Extract the bytes from the PDU and convert them to the physical value."""
-        pass
-
+        raise NotImplementedError
 
 class DataObjectProperty(DopBase):
     """This class represents a DATA-OBJECT-PROP."""
 
     def __init__(self,
+                 *,
                  odx_id: OdxLinkId,
                  short_name: str,
                  diag_coded_type: DiagCodedType,
                  physical_type: PhysicalType,
                  compu_method: CompuMethod,
-                 unit_ref: Optional[OdxLinkRef] = None,
-                 long_name: Optional[str] = None,
-                 description: Optional[str] = None,
-                 is_visible_raw: Optional[bool] = None,
-                 sdgs: List[SpecialDataGroup] = [],
+                 unit_ref: Optional[OdxLinkRef],
+                 long_name: Optional[str],
+                 description: Optional[str],
+                 is_visible_raw: Optional[bool],
+                 sdgs: List[SpecialDataGroup],
                  ):
         super().__init__(odx_id=odx_id,
                          short_name=short_name,
@@ -106,37 +104,46 @@ class DataObjectProperty(DopBase):
         long_name = et_element.findtext("LONG-NAME")
         description = create_description_from_et(et_element.find("DESC"))
         sdgs = create_sdgs_from_et(et_element.find("SDGS"), doc_frags)
+        is_visible_raw = odxstr_to_bool(et_element.get("IS-VISIBLE"))
 
         diag_coded_type = create_any_diag_coded_type_from_et(
             et_element.find("DIAG-CODED-TYPE"), doc_frags)
 
-        physical_type = PhysicalType.from_et(
-            et_element.find("PHYSICAL-TYPE"), doc_frags)
-        compu_method = create_any_compu_method_from_et(et_element.find(
-            "COMPU-METHOD"), doc_frags, diag_coded_type.base_data_type, physical_type.base_data_type)
+        physical_type = PhysicalType.from_et(et_element.find("PHYSICAL-TYPE"), doc_frags)
+        compu_method = create_any_compu_method_from_et(et_element.find("COMPU-METHOD"),
+                                                       doc_frags,
+                                                       diag_coded_type.base_data_type,
+                                                       physical_type.base_data_type)
+        unit_ref = OdxLinkRef.from_et(et_element.find("UNIT-REF"), doc_frags)
 
         if et_element.tag == "DATA-OBJECT-PROP":
-            unit_ref = OdxLinkRef.from_et(et_element.find("UNIT-REF"), doc_frags)
-            dop = DataObjectProperty(odx_id,
-                                     short_name,
-                                     diag_coded_type,
-                                     physical_type,
-                                     compu_method,
-                                     unit_ref=unit_ref,
+            dop = DataObjectProperty(odx_id=odx_id,
+                                     short_name=short_name,
                                      long_name=long_name,
                                      description=description,
+                                     is_visible_raw=is_visible_raw,
+                                     diag_coded_type=diag_coded_type,
+                                     physical_type=physical_type,
+                                     compu_method=compu_method,
+                                     unit_ref=unit_ref,
                                      sdgs=sdgs)
         else:
-            dtclist: List[Union[DiagnosticTroubleCode, DtcRef]] = list()
-            dtcs_elem = et_element.find("DTCS")
-            if dtcs_elem is not None:
-                for dtc_elem in dtcs_elem:
-                    if dtc_elem.tag == "DTC":
-                        dtclist.append(DiagnosticTroubleCode.from_et(dtc_elem, doc_frags))
-                    elif dtc_elem.tag == "DTC-REF":
-                        dtclist.append(DtcRef.from_et(dtc_elem, doc_frags))
+            dtclist: List[Union[DiagnosticTroubleCode, OdxLinkRef]] = list()
+            if (dtcs_elem := et_element.find("DTCS")) is not None:
+                for dtc_proxy_elem in dtcs_elem:
+                    if dtc_proxy_elem.tag == "DTC":
+                        dtclist.append(DiagnosticTroubleCode.from_et(dtc_proxy_elem, doc_frags))
+                    elif dtc_proxy_elem.tag == "DTC-REF":
+                        dtclist.append(OdxLinkRef.from_et(dtc_proxy_elem, doc_frags))
+
+            # TODO: NOT-INHERITED-DTC-SNREFS
+            linked_dtc_dops = [
+                cast(OdxLinkRef, OdxLinkRef.from_et(dtc_ref_elem, doc_frags))
+                for dtc_ref_elem in et_element.iterfind("LINKED-DTC-DOPS/"
+                                                        "LINKED-DTC-DOP/"
+                                                        "DTC-DOP-REF")
+            ]
 
-            is_visible_raw = odxstr_to_bool(et_element.get("IS-VISIBLE"))
             dop = DtcDop(odx_id=odx_id,
                          short_name=short_name,
                          long_name=long_name,
@@ -144,7 +151,9 @@ class DataObjectProperty(DopBase):
                          diag_coded_type=diag_coded_type,
                          physical_type=physical_type,
                          compu_method=compu_method,
-                         dtcs=dtclist,
+                         unit_ref=unit_ref,
+                         dtcs_raw=dtclist,
+                         linked_dtc_dops=linked_dtc_dops,
                          is_visible_raw=is_visible_raw,
                          sdgs=sdgs)
         return dop
@@ -232,13 +241,13 @@ class DataObjectProperty(DopBase):
 @dataclass
 class DiagnosticTroubleCode:
     trouble_code: int
-    odx_id: Optional[OdxLinkId] = None
-    short_name: Optional[str] = None
-    text: Optional[str] = None
-    display_trouble_code: Optional[str] = None
-    level: Union[bytes, bytearray, None] = None
-    is_temporary_raw: Optional[bool] = None
-    sdgs: List[SpecialDataGroup] = field(default_factory=list)
+    odx_id: Optional[OdxLinkId]
+    short_name: Optional[str]
+    text: Optional[str]
+    display_trouble_code: Optional[str]
+    level: Union[bytes, bytearray, None]
+    is_temporary_raw: Optional[bool]
+    sdgs: List[SpecialDataGroup]
 
     @property
     def is_temporary(self) -> bool:
@@ -282,73 +291,23 @@ class DiagnosticTroubleCode:
         for sdg in self.sdgs:
             sdg._resolve_references(odxlinks)
 
-class DtcRef:
-    """A proxy for DiagnosticTroubleCode.
-    The DTC is referenced by ID and the ID-REF
-    is resolved after loading the pdx database.
-    """
-
-    def __init__(self, dtc_ref: OdxLinkRef):
-        self.dtc_ref = dtc_ref
-        self.dtc: Optional[DiagnosticTroubleCode] = None
-
-    @staticmethod
-    def from_et(et_element, doc_frags: List[OdxDocFragment]) -> "DtcRef":
-        dtc_ref = OdxLinkRef.from_et(et_element, doc_frags)
-        assert dtc_ref is not None
-
-        return DtcRef(dtc_ref)
-
-    def _resolve_references(self, odxlinks: OdxLinkDatabase):
-        dtc = odxlinks.resolve(self.dtc_ref)
-        assert isinstance(dtc, DiagnosticTroubleCode),\
-            f"DTC-REF {self.dtc_ref} references an object of type {type(dtc)} " \
-            f"instead of a DiagnosticTroubleCode."
-        self.dtc = dtc
-
-    @property
-    def odx_id(self):
-        return self.dtc.odx_id
-
-    @property
-    def short_name(self):
-        return self.dtc.short_name
-
-    @property
-    def trouble_code(self):
-        return self.dtc.trouble_code
-
-    @property
-    def text(self):
-        return self.dtc.text
-
-    @property
-    def display_trouble_code(self):
-        return self.dtc.display_trouble_code
-
-    @property
-    def level(self):
-        return self.dtc.level
-
-    @property
-    def is_temporary(self):
-        return self.dtc.is_temporary
-
 class DtcDop(DataObjectProperty):
     """ A DOP describing a diagnostic trouble code """
 
     def __init__(self,
+                 *,
                  odx_id: OdxLinkId,
                  short_name: str,
                  diag_coded_type: DiagCodedType,
                  physical_type: PhysicalType,
                  compu_method: CompuMethod,
-                 dtcs: List[Union[DiagnosticTroubleCode, DtcRef]],
-                 is_visible_raw: bool = False,
-                 linked_dtc_dops: bool = False,
-                 long_name: Optional[str] = None,
-                 description: Optional[str] = None,
-                 sdgs: List[SpecialDataGroup] = [],
+                 unit_ref: Optional[OdxLinkRef],
+                 dtcs_raw: List[Union[DiagnosticTroubleCode, OdxLinkRef]],
+                 is_visible_raw: bool,
+                 linked_dtc_dops: List[OdxLinkRef],
+                 long_name: Optional[str],
+                 description: Optional[str],
+                 sdgs: List[SpecialDataGroup],
                  ):
         super().__init__(odx_id=odx_id,
                          short_name=short_name,
@@ -357,11 +316,16 @@ class DtcDop(DataObjectProperty):
                          diag_coded_type=diag_coded_type,
                          physical_type=physical_type,
                          compu_method=compu_method,
+                         unit_ref=unit_ref,
                          is_visible_raw=is_visible_raw,
                          sdgs=sdgs)
-        self.dtcs = dtcs
+        self.dtcs_raw = dtcs_raw
         self.linked_dtc_dops = linked_dtc_dops
 
+    @property
+    def dtcs(self) -> NamedItemList[DiagnosticTroubleCode]:
+        return self._dtcs
+
     def convert_bytes_to_physical(self, decode_state, bit_position: int = 0):
         trouble_code, next_byte = \
             super().convert_bytes_to_physical(decode_state,
@@ -380,7 +344,14 @@ class DtcDop(DataObjectProperty):
         # diagnostic description file is incomplete. We do not bail
         # out but we cannot provide an interpretation for it out of the
         # box...
-        dtc = DiagnosticTroubleCode(trouble_code=trouble_code)
+        dtc = DiagnosticTroubleCode(trouble_code=trouble_code,
+                                    odx_id=None,
+                                    short_name=None,
+                                    text=None,
+                                    display_trouble_code=None,
+                                    level=None,
+                                    is_temporary_raw=None,
+                                    sdgs=[])
 
         return dtc, next_byte
 
@@ -404,16 +375,22 @@ class DtcDop(DataObjectProperty):
     def _build_odxlinks(self) -> Dict[OdxLinkId, Any]:
         odxlinks = super()._build_odxlinks()
         odxlinks[self.odx_id] = self
-        for dtc in self.dtcs:
-            if isinstance(dtc, DiagnosticTroubleCode):
-                assert dtc.odx_id is not None
-                odxlinks[dtc.odx_id] = dtc
-                odxlinks.update(dtc._build_odxlinks())
+        for dtc_proxy in self.dtcs_raw:
+            if isinstance(dtc_proxy, DiagnosticTroubleCode):
+                assert dtc_proxy.odx_id is not None
+                odxlinks[dtc_proxy.odx_id] = dtc_proxy
+                odxlinks.update(dtc_proxy._build_odxlinks())
 
         return odxlinks
 
     def _resolve_references(self, odxlinks: OdxLinkDatabase):
         super()._resolve_references(odxlinks)
 
-        for dtc in self.dtcs:
-            dtc._resolve_references(odxlinks)
+        self._dtcs: NamedItemList[DiagnosticTroubleCode] \
+            = NamedItemList(short_name_as_id)
+        for dtc_proxy in self.dtcs_raw:
+            if isinstance(dtc_proxy, DiagnosticTroubleCode):
+                self._dtcs.append(dtc_proxy)
+            elif isinstance(dtc_proxy, OdxLinkRef):
+                dtc = odxlinks.resolve(dtc_proxy, DiagnosticTroubleCode)
+                self._dtcs.append(dtc)
