@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 import abc
 import math
 from typing import Any, Optional, Union, List
@@ -28,10 +27,11 @@ ODX_TYPE_TO_FORMAT_LETTER = {
 
 class DiagCodedType(abc.ABC):
     def __init__(self,
+                 *,
                  base_data_type: Union[str, DataType],
                  dct_type: str,
-                 base_type_encoding=None,
-                 is_highlow_byte_order_raw: Optional[bool] = None):
+                 base_type_encoding: Optional[str],
+                 is_highlow_byte_order_raw: Optional[bool]):
         self.base_data_type = DataType(base_data_type)
         self.dct_type = dct_type
         self.base_type_encoding = base_type_encoding
@@ -200,11 +200,12 @@ class DiagCodedType(abc.ABC):
 
 class LeadingLengthInfoType(DiagCodedType):
     def __init__(self,
-                 base_data_type,
-                 bit_length,
-                 base_type_encoding=None,
-                 is_highlow_byte_order_raw=True):
-        super().__init__(base_data_type,
+                 *,
+                 base_data_type: str,
+                 bit_length: int,
+                 base_type_encoding: Optional[str],
+                 is_highlow_byte_order_raw: Optional[bool]):
+        super().__init__(base_data_type=base_data_type,
                          dct_type="LEADING-LENGTH-INFO-TYPE",
                          base_type_encoding=base_type_encoding,
                          is_highlow_byte_order_raw=is_highlow_byte_order_raw)
@@ -273,13 +274,14 @@ class LeadingLengthInfoType(DiagCodedType):
 
 class MinMaxLengthType(DiagCodedType):
     def __init__(self,
-                 base_data_type,
-                 min_length,
-                 termination,
-                 max_length=None,
-                 base_type_encoding=None,
-                 is_highlow_byte_order_raw=None):
-        super().__init__(base_data_type,
+                 *,
+                 base_data_type: Union[str, DataType],
+                 min_length: int,
+                 termination: str,
+                 max_length: Optional[int],
+                 base_type_encoding: Optional[str],
+                 is_highlow_byte_order_raw: Optional[bool]):
+        super().__init__(base_data_type=base_data_type,
                          dct_type="MIN-MAX-LENGTH-TYPE",
                          base_type_encoding=base_type_encoding,
                          is_highlow_byte_order_raw=is_highlow_byte_order_raw)
@@ -414,11 +416,12 @@ class MinMaxLengthType(DiagCodedType):
 
 class ParamLengthInfoType(DiagCodedType):
     def __init__(self,
+                 *,
                  base_data_type: Union[str, DataType],
                  length_key_id: OdxLinkId,
-                 base_type_encoding=None,
-                 is_highlow_byte_order_raw=True):
-        super().__init__(base_data_type,
+                 base_type_encoding: Optional[str],
+                 is_highlow_byte_order_raw: Optional[bool]):
+        super().__init__(base_data_type=base_data_type,
                          dct_type="PARAM-LENGTH-INFO-TYPE",
                          base_type_encoding=base_type_encoding,
                          is_highlow_byte_order_raw=is_highlow_byte_order_raw)
@@ -487,19 +490,20 @@ class ParamLengthInfoType(DiagCodedType):
 class StandardLengthType(DiagCodedType):
 
     def __init__(self,
+                 *,
                  base_data_type: Union[str, DataType],
                  bit_length: int,
-                 bit_mask = None,
-                 condensed: Optional[bool] = None,
-                 base_type_encoding = None,
-                 is_highlow_byte_order_raw = True):
-        super().__init__(base_data_type,
+                 bit_mask: Optional[int],
+                 is_condensed_raw: Optional[bool],
+                 base_type_encoding: Optional[str],
+                 is_highlow_byte_order_raw: Optional[bool]):
+        super().__init__(base_data_type=base_data_type,
                          dct_type="STANDARD-LENGTH-TYPE",
                          base_type_encoding=base_type_encoding,
                          is_highlow_byte_order_raw=is_highlow_byte_order_raw)
         self.bit_length = bit_length
         self.bit_mask = bit_mask
-        self.condensed = condensed
+        self.is_condensed_raw = is_condensed_raw
 
     def convert_internal_to_bytes(self, internal_value, encode_state: EncodeState, bit_position: int) -> bytes:
         return self._to_bytes(internal_value,
@@ -522,8 +526,8 @@ class StandardLengthType(DiagCodedType):
         repr_str = f"StandardLengthType(base_data_type='{self.base_data_type}', bit_length={self.bit_length}"
         if self.bit_mask is not None:
             repr_str += f", bit_mask={self.bit_mask}"
-        if self.condensed:
-            repr_str += f", condensed={self.condensed}"
+        if self.is_condensed_raw:
+            repr_str += f", is_condensed_raw={self.is_condensed_raw}"
         if self.base_type_encoding is not None:
             repr_str += f", base_type_encoding={self.base_type_encoding}"
         if not self.is_highlow_byte_order:
@@ -547,7 +551,7 @@ def create_any_diag_coded_type_from_et(et_element, doc_frags: List[OdxDocFragmen
     bit_length = None
     if dct_type == "LEADING-LENGTH-INFO-TYPE":
         bit_length = int(et_element.findtext("BIT-LENGTH"))
-        return LeadingLengthInfoType(base_data_type,
+        return LeadingLengthInfoType(base_data_type=base_data_type,
                                      bit_length=bit_length,
                                      base_type_encoding=base_type_encoding,
                                      is_highlow_byte_order_raw=is_highlow_byte_order_raw)
@@ -558,7 +562,7 @@ def create_any_diag_coded_type_from_et(et_element, doc_frags: List[OdxDocFragmen
             max_length = int(et_element.findtext("MAX-LENGTH"))
         termination = et_element.get("TERMINATION")
 
-        return MinMaxLengthType(base_data_type,
+        return MinMaxLengthType(base_data_type=base_data_type,
                                 min_length=min_length,
                                 max_length=max_length,
                                 termination=termination,
@@ -575,8 +579,8 @@ def create_any_diag_coded_type_from_et(et_element, doc_frags: List[OdxDocFragmen
         length_key_elem = et_element.find("LENGTH-KEY-REF")
         length_key_id = OdxLinkId(length_key_elem.attrib["ID-REF"], doc_frags)
 
-        return ParamLengthInfoType(base_data_type,
-                                   length_key_id,
+        return ParamLengthInfoType(base_data_type=base_data_type,
+                                   length_key_id=length_key_id,
                                    base_type_encoding=base_type_encoding,
                                    is_highlow_byte_order_raw=is_highlow_byte_order_raw)
     elif dct_type == "STANDARD-LENGTH-TYPE":
@@ -584,11 +588,11 @@ def create_any_diag_coded_type_from_et(et_element, doc_frags: List[OdxDocFragmen
         bit_mask = None
         if et_element.find("BIT-MASK"):
             bit_mask = et_element.findtext("BIT-MASK")
-        condensed = odxstr_to_bool(et_element.get("CONDENSED"))
-        return StandardLengthType(base_data_type,
-                                  bit_length,
+        is_condensed_raw = odxstr_to_bool(et_element.get("CONDENSED"))
+        return StandardLengthType(base_data_type=base_data_type,
+                                  bit_length=bit_length,
                                   bit_mask=bit_mask,
-                                  condensed=condensed,
+                                  is_condensed_raw=is_condensed_raw,
                                   base_type_encoding=base_type_encoding,
                                   is_highlow_byte_order_raw=is_highlow_byte_order_raw)
     raise NotImplementedError(f"I do not know the diag-coded-type {dct_type}")
