@@ -1,9 +1,7 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
-
 import abc
-from typing import Optional, Union, List
+from typing import TYPE_CHECKING, Optional, Union, List
 import warnings
 
 from ..decodestate import DecodeState
@@ -13,16 +11,20 @@ from ..odxlink import OdxLinkDatabase
 from ..globals import logger
 from ..specialdata import SpecialDataGroup
 
+if TYPE_CHECKING:
+    from ..diaglayer import DiagLayer
+
 class Parameter(abc.ABC):
     def __init__(self,
+                 *,
                  short_name: str,
                  parameter_type: str,
-                 long_name: Optional[str] = None,
-                 byte_position: Optional[int] = None,
-                 bit_position: Optional[int] = None,
-                 semantic: Optional[str] = None,
-                 description: Optional[str] = None,
-                 sdgs: List[SpecialDataGroup] = []) -> None:
+                 long_name: Optional[str],
+                 byte_position: Optional[int],
+                 bit_position: Optional[int],
+                 semantic: Optional[str],
+                 description: Optional[str],
+                 sdgs: List[SpecialDataGroup]) -> None:
         self.short_name: str = short_name
         self.long_name: Optional[str] = long_name
         self.byte_position: Optional[int] = byte_position
@@ -40,7 +42,9 @@ class Parameter(abc.ABC):
 
         return result
 
-    def _resolve_references(self, odxlinks: OdxLinkDatabase) -> None:
+    def _resolve_references(self,
+                            parent_dl: "DiagLayer",
+                            odxlinks: OdxLinkDatabase) -> None:
         for sdg in self.sdgs:
             sdg._resolve_references(odxlinks)
 
