@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 from typing import List, Iterable, Optional, Union
 from xml.etree import ElementTree
 
@@ -21,20 +20,21 @@ from .admindata import AdminData
 
 class DiagService:
     def __init__(self,
+                 *,
                  odx_id: OdxLinkId,
                  short_name: str,
                  request: Union[OdxLinkRef, Request],
                  positive_responses: Union[Iterable[OdxLinkRef], Iterable[Response]],
                  negative_responses: Union[Iterable[OdxLinkRef], Iterable[Response]],
-                 long_name: Optional[str] = None,
-                 admin_data: Optional[AdminData] = None,
-                 description: Optional[str] = None,
-                 semantic: Optional[str] = None,
-                 audience: Optional[Audience] = None,
-                 functional_class_refs: Iterable[OdxLinkRef] = [],
-                 pre_condition_state_refs: Iterable[OdxLinkRef] = [],
-                 state_transition_refs: Iterable[OdxLinkRef] = [],
-                 sdgs: List[SpecialDataGroup] = []):
+                 long_name: Optional[str],
+                 admin_data: Optional[AdminData],
+                 description: Optional[str],
+                 semantic: Optional[str],
+                 audience: Optional[Audience],
+                 functional_class_refs: Iterable[OdxLinkRef],
+                 pre_condition_state_refs: Iterable[OdxLinkRef],
+                 state_transition_refs: Iterable[OdxLinkRef],
+                 sdgs: List[SpecialDataGroup]):
         """Constructs the service.
 
         Parameters:
@@ -161,11 +161,11 @@ class DiagService:
 
         sdgs = create_sdgs_from_et(et_element.find("SDGS"), doc_frags)
 
-        return DiagService(odx_id,
-                           short_name,
-                           request_ref,
-                           pos_res_refs,
-                           neg_res_refs,
+        return DiagService(odx_id=odx_id,
+                           short_name=short_name,
+                           request=request_ref,
+                           positive_responses=pos_res_refs,
+                           negative_responses=neg_res_refs,
                            long_name=long_name,
                            description=description,
                            admin_data=admin_data,
