@@ -1,21 +1,20 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 from dataclasses import dataclass
 from typing import Optional, List, Dict, Any
 
 from .odxlink import OdxLinkId, OdxDocFragment, OdxLinkDatabase
 
-@dataclass()
+@dataclass
 class StateTransition:
     """
     Corresponds to STATE.
     """
     odx_id: OdxLinkId
     short_name: str
-    long_name: Optional[str] = None
-    source_short_name: Optional[str] = None
-    target_short_name: Optional[str] = None
+    long_name: Optional[str]
+    source_short_name: Optional[str]
+    target_short_name: Optional[str]
 
     @staticmethod
     def from_et(et_element, doc_frags: List[OdxDocFragment]) \
